"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fixtures_1 = require("../lib/fixtures");
const snippet_1 = require("../lib/snippet");
const testutil_1 = require("./testutil");
const location = (0, testutil_1.testSnippetLocation)('where');
describe('fixturize', () => {
    test('snippet retains properties', () => {
        const snippet = {
            visibleSource: 'visibleSource',
            location,
            parameters: {
                [snippet_1.SnippetParameters.$PROJECT_DIRECTORY]: 'directory',
                [snippet_1.SnippetParameters.NO_FIXTURE]: '',
                key: 'value',
            },
            strict: true,
        };
        expect((0, fixtures_1.fixturize)(snippet)).toEqual(expect.objectContaining(snippet));
    });
    test('separates imports and declarations', () => {
        const source = `import * as ns from 'mod';
declare const mock: Tpe;
const val = new Cls();`;
        const snippet = {
            visibleSource: source,
            location,
            parameters: {
                [snippet_1.SnippetParameters.$PROJECT_DIRECTORY]: 'test',
            },
            strict: true,
        };
        const fixturizedSnippet = (0, fixtures_1.fixturize)(snippet);
        expect(fixturizedSnippet.completeSource).toBe(`// Hoisted imports begin after !show marker below
/// !show
import * as ns from 'mod';
declare const mock: Tpe;
/// !hide
// Hoisted imports ended before !hide marker above
// Code snippet begins after !show marker below
/// !show

const val = new Cls();
/// !hide
// Code snippet ended before !hide marker above
`);
    });
});
//# sourceMappingURL=fixtures.test.js.map